;; Generated package description from slime.el  -*- no-byte-compile: t -*-
(define-package "slime" "2.32.0.20251220.17" "Superior Lisp Interaction Mode for Emacs" '((emacs "24.3") (macrostep "0.9")) :commit "9b59a6dcf1c1210463b5a68ff3db21f8af62233d" :keywords '("languages" "lisp" "slime") :url "https://github.com/slime/slime")
